@@ -332,13 +332,13 @@ describe('Drill to detail modal', () => {
       });
     });
 
-    describe('Time-Series Line Chart', () => {
+    describe('Line Chart', () => {
       it('opens the modal with the correct filters', () => {
         testTimeChart('echarts_timeseries_line');
       });
     });
 
-    describe('Time-series Bar Chart', () => {
+    describe('Bar Chart', () => {
       it('opens the modal with the correct filters', () => {
         interceptSamples();
 
@@ -372,13 +372,13 @@ describe('Drill to detail modal', () => {
       });
     });
 
-    describe('Time-Series Area Chart', () => {
+    describe('Area Chart', () => {
       it('opens the modal with the correct filters', () => {
         testTimeChart('echarts_area');
       });
     });
 
-    describe('Time-Series Scatter Chart', () => {
+    describe('Scatter Chart', () => {
       it('opens the modal with the correct filters', () => {
         testTimeChart('echarts_timeseries_scatter');
       });
@@ -509,19 +509,19 @@ describe('Drill to detail modal', () => {
       });
     });
 
-    describe('Time-Series Generic Chart', () => {
+    describe('Generic Chart', () => {
       it('opens the modal with the correct filters', () => {
         testTimeChart('echarts_timeseries');
       });
     });
 
-    describe('Time-Series Smooth Chart', () => {
+    describe('Smooth Chart', () => {
       it('opens the modal with the correct filters', () => {
         testTimeChart('echarts_timeseries_smooth');
       });
     });
 
-    describe('Time-Series Step Line Chart', () => {
+    describe('Step Line Chart', () => {
       it('opens the modal with the correct filters', () => {
         testTimeChart('echarts_timeseries_step');
       });
