@@ -123,9 +123,6 @@ describe('SqlLab query panel', () => {
       .eq(0) // save
       .click();
 
-    // visit saved queries
-    cy.visit('/sqllab/my_queries/');
-
     // first row contains most recent link, follow back to SqlLab
     cy.get('table tr:first-child a[href*="savedQueryId"').click();
 
