@@ -17,7 +17,7 @@
  * under the License.
  */
 import { QueryResponse } from '@superset-ui/core';
-import { Dataset, isColumnMeta, isDataset } from '../types';
+import { Dataset, isDataset, isQueryResponse } from '../types';
 
 /**
  * Convert Datasource columns to column choices
@@ -25,11 +25,13 @@ import { Dataset, isColumnMeta, isDataset } from '../types';
 export default function columnChoices(
   datasource?: Dataset | QueryResponse | null,
 ): [string, string][] {
-  if (isDataset(datasource) && isColumnMeta(datasource.columns[0])) {
+  if (isDataset(datasource) || isQueryResponse(datasource)) {
     return datasource.columns
       .map((col): [string, string] => [
         col.column_name,
-        col.verbose_name || col.column_name,
+        'verbose_name' in col
+          ? col.verbose_name || col.column_name
+          : col.column_name,
       ])
       .sort((opt1, opt2) =>
         opt1[1].toLowerCase() > opt2[1].toLowerCase() ? 1 : -1,
