@@ -24,3 +24,10 @@ export interface ColorsInitLookup {
 export interface ColorsLookup {
   [key: string]: string;
 }
+
+export interface RgbaColor {
+  r: number;
+  g: number;
+  b: number;
+  a: number;
+}
