@@ -52,8 +52,8 @@ export const TestComponent = ({
       style={{
         width,
         height,
-        backgroundColor: theme.colors.primary.base,
-        color: theme.colors.grayscale.light5,
+        backgroundColor: theme.colors.primary.light5,
+        color: theme.colors.grayscale.light3,
         display: 'flex',
         flexDirection: 'column',
         alignItems: 'center',
