@@ -22,7 +22,6 @@ import {
   ControlPanelConfig,
   ControlSubSectionHeader,
   getStandardizedControls,
-  sections,
   sharedControls,
 } from '@superset-ui/chart-controls';
 import { DEFAULT_FORM_DATA } from './types';
@@ -41,7 +40,6 @@ const optionalEntity = {
 
 const controlPanel: ControlPanelConfig = {
   controlPanelSections: [
-    sections.legacyRegularTime,
     {
       label: t('Query'),
       expanded: true,
