@@ -32,9 +32,6 @@ import QueryLimitSelect, {
 const middlewares = [thunk];
 const mockStore = configureStore(middlewares);
 
-jest.mock('src/components/DeprecatedSelect', () => () => (
-  <div data-test="mock-deprecated-select" />
-));
 jest.mock('src/components/Select/Select', () => () => (
   <div data-test="mock-deprecated-select-select" />
 ));
@@ -119,8 +116,8 @@ describe('QueryLimitSelect', () => {
     const expectedLabels = [10, 100, 1000, 10000, 50000].map(i =>
       convertToNumWithSpaces(i),
     );
-    const actualLabels = getAllByRole('menuitem').map(elem =>
-      elem.textContent?.trim(),
+    const actualLabels = getAllByRole('menuitem').map(
+      elem => elem.textContent?.trim(),
     );
 
     expect(actualLabels).toEqual(expectedLabels);
@@ -139,8 +136,8 @@ describe('QueryLimitSelect', () => {
     await waitFor(() => expect(getByRole('menu')).toBeInTheDocument());
 
     const expectedLabels = [5].map(i => convertToNumWithSpaces(i));
-    const actualLabels = getAllByRole('menuitem').map(elem =>
-      elem.textContent?.trim(),
+    const actualLabels = getAllByRole('menuitem').map(
+      elem => elem.textContent?.trim(),
     );
 
     expect(actualLabels).toEqual(expectedLabels);
@@ -161,8 +158,8 @@ describe('QueryLimitSelect', () => {
     const expectedLabels = [10, 100, 1000, 10000].map(i =>
       convertToNumWithSpaces(i),
     );
-    const actualLabels = getAllByRole('menuitem').map(elem =>
-      elem.textContent?.trim(),
+    const actualLabels = getAllByRole('menuitem').map(
+      elem => elem.textContent?.trim(),
     );
 
     expect(actualLabels).toEqual(expectedLabels);
