@@ -44,7 +44,7 @@ export const LOCALE: Locale = {
   prefixMonths: t('in'),
   prefixMonthDays: t('on'),
   prefixWeekDays: t('on'),
-  prefixWeekDaysForMonthAndYearPeriod: t('and'),
+  prefixWeekDaysForMonthAndYearPeriod: t('or'),
   prefixHours: t('at'),
   prefixMinutes: t(':'),
   prefixMinutesForHourPeriod: t('at'),
@@ -110,22 +110,99 @@ export const CronPicker = styled((props: CronProps) => (
     <ReactCronPicker locale={LOCALE} {...props} />
   </ConfigProvider>
 ))`
-  .react-js-cron-field {
-    margin-bottom: 0px;
-  }
-  .react-js-cron-select:not(.react-js-cron-custom-select) > div:first-of-type,
-  .react-js-cron-custom-select {
-    border-radius: ${({ theme }) => theme.gridUnit}px;
-    background-color: ${({ theme }) =>
-      theme.colors.grayscale.light4} !important;
-  }
-  .react-js-cron-custom-select > div:first-of-type {
-    border-radius: ${({ theme }) => theme.gridUnit}px;
-  }
-  .react-js-cron-custom-select .ant-select-selection-placeholder {
-    flex: auto;
-  }
-  .react-js-cron-custom-select .ant-select-selection-overflow-item {
-    align-self: center;
-  }
+  ${({ theme }) => `
+
+    /* Boilerplate styling for ReactCronPicker imported explicitly in GlobalStyles.tsx */
+
+    /* When year period is selected */
+
+    :has(.react-js-cron-months) {
+      display: grid !important;
+      grid-template-columns: repeat(2, 50%);
+      column-gap: ${theme.gridUnit}px;
+      row-gap: ${theme.gridUnit * 2}px;
+      div:has(.react-js-cron-hours) {
+        grid-column: span 2;
+        display: flex;
+        justify-content: space-between;
+        .react-js-cron-field {
+          width: 50%;
+        }
+      }
+    }
+
+    /* When month period is selected */
+
+    :not(:has(.react-js-cron-months)) {
+      display: grid;
+      grid-template-columns: repeat(2, 50%);
+      column-gap: ${theme.gridUnit}px;
+      row-gap: ${theme.gridUnit * 2}px;
+      .react-js-cron-period {
+        grid-column: span 2;
+      }
+      div:has(.react-js-cron-hours) {
+        grid-column: span 2;
+        display: flex;
+        justify-content: space-between;
+        .react-js-cron-field {
+          width: 50%;
+        }
+      }
+    }
+
+    /* When week period is selected */
+
+    :not(:has(.react-js-cron-month-days)) {
+      .react-js-cron-week-days {
+        grid-column: span 2;
+      }
+    }
+
+    /* For proper alignment of inputs and span elements */
+
+    :not(div:has(.react-js-cron-hours)) {
+      display: flex;
+      flex-wrap: nowrap;
+    }
+
+    div:has(.react-js-cron-hours) {
+      width: 100%;
+    }
+
+    .react-js-cron-minutes > span {
+      padding-left: ${theme.gridUnit}px;
+    }
+
+    /* Sizing of select container */
+
+    .react-js-cron-select.ant-select {
+      width: 100%;
+      .ant-select-selector {
+        flex-wrap: nowrap;
+      }
+    }
+
+    .react-js-cron-field {
+      width: 100%;
+      margin-bottom: 0px;
+      > span {
+        margin-left: 0px;
+      }
+    }
+
+    .react-js-cron-custom-select .ant-select-selection-placeholder {
+      flex: auto;
+      border-radius: ${theme.gridUnit}px;
+    }
+
+    .react-js-cron-custom-select .ant-select-selection-overflow-item {
+      align-self: center;
+    }
+
+    .react-js-cron-select > div:first-of-type,
+    .react-js-cron-custom-select {
+      border-radius: ${theme.gridUnit}px;
+    }
+  `}
 `;
