@@ -21,4 +21,5 @@ import FormItem from './FormItem';
 import FormLabel from './FormLabel';
 import LabeledErrorBoundInput from './LabeledErrorBoundInput';
 
-export { Form, FormItem, FormLabel, LabeledErrorBoundInput, FormProps };
+export { Form, FormItem, FormLabel, LabeledErrorBoundInput };
+export type { FormProps };
