@@ -1039,6 +1039,7 @@ test('pasting an existing option does not duplicate it in multiple mode', async
       options={options}
       mode="multiple"
       allowSelectAll={false}
+      allowNewOptions
     />,
   );
   await open();
@@ -1053,6 +1054,19 @@ test('pasting an existing option does not duplicate it in multiple mode', async
   expect(await findAllSelectOptions()).toHaveLength(4);
 });
 
+test('pasting an non-existent option should not add it if allowNewOptions is false', async () => {
+  render(<Select {...defaultProps} options={[]} allowNewOptions={false} />);
+  await open();
+  const input = getElementByClassName('.ant-select-selection-search-input');
+  const paste = createEvent.paste(input, {
+    clipboardData: {
+      getData: () => 'John',
+    },
+  });
+  fireEvent(input, paste);
+  expect(await findAllSelectOptions()).toHaveLength(0);
+});
+
 test('does not fire onChange if the same value is selected in single mode', async () => {
   const onChange = jest.fn();
   render(<Select {...defaultProps} onChange={onChange} />);
