@@ -18,6 +18,7 @@
  */
 import React from 'react';
 import { render } from 'spec/helpers/testing-library';
+import { screen } from '@testing-library/react';
 import TagType from 'src/types/TagType';
 import Tag from './Tag';
 
@@ -33,3 +34,23 @@ test('should render', () => {
   const { container } = render(<Tag {...mockedProps} />);
   expect(container).toBeInTheDocument();
 });
+
+test('should render shortname properly', () => {
+  const { container } = render(<Tag {...mockedProps} />);
+  expect(container).toBeInTheDocument();
+  expect(screen.getByTestId('tag')).toBeInTheDocument();
+  expect(screen.getByTestId('tag')).toHaveTextContent(mockedProps.name);
+});
+
+test('should render longname properly', () => {
+  const longNameProps = {
+    ...mockedProps,
+    name: 'very-long-tag-name-that-truncates',
+  };
+  const { container } = render(<Tag {...longNameProps} />);
+  expect(container).toBeInTheDocument();
+  expect(screen.getByTestId('tag')).toBeInTheDocument();
+  expect(screen.getByTestId('tag')).toHaveTextContent(
+    `${longNameProps.name.slice(0, 20)}...`,
+  );
+});
