@@ -603,11 +603,6 @@ export function setActiveTab(tabId, prevTabId) {
   return { type: SET_ACTIVE_TAB, tabId, prevTabId };
 }
 
-export const SET_ACTIVE_TABS = 'SET_ACTIVE_TABS';
-export function setActiveTabs(activeTabs) {
-  return { type: SET_ACTIVE_TABS, activeTabs };
-}
-
 export const SET_FOCUSED_FILTER_FIELD = 'SET_FOCUSED_FILTER_FIELD';
 export function setFocusedFilterField(chartId, column) {
   return { type: SET_FOCUSED_FILTER_FIELD, chartId, column };
