@@ -17,7 +17,8 @@
  * under the License.
  */
 import React from 'react';
-import { render } from 'spec/helpers/testing-library';
+import { render, screen } from 'spec/helpers/testing-library';
+import userEvent from '@testing-library/user-event';
 
 import HoverMenu from 'src/dashboard/components/menu/HoverMenu';
 
@@ -25,3 +26,16 @@ test('should render a div.hover-menu', () => {
   const { container } = render(<HoverMenu />);
   expect(container.querySelector('.hover-menu')).toBeInTheDocument();
 });
+
+test('should call onHover when mouse enters and leaves', () => {
+  const onHover = jest.fn();
+  render(<HoverMenu onHover={onHover} />);
+
+  const hoverMenu = screen.getByTestId('hover-menu');
+
+  userEvent.hover(hoverMenu);
+  expect(onHover).toBeCalledWith({ isHovered: true });
+
+  userEvent.unhover(hoverMenu);
+  expect(onHover).toBeCalledWith({ isHovered: false });
+});
