@@ -16,8 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-
-import { FeatureFlag, NativeFilterType } from '@superset-ui/core';
+import { NativeFilterType } from '@superset-ui/core';
 import React from 'react';
 import { render, screen, waitFor } from 'spec/helpers/testing-library';
 import HorizontalBar from './Horizontal';
@@ -32,11 +31,6 @@ const defaultProps = {
   onSelectionChange: jest.fn(),
 };
 
-// @ts-ignore
-global.featureFlags = {
-  [FeatureFlag.DASHBOARD_NATIVE_FILTERS]: true,
-};
-
 const renderWrapper = (overrideProps?: Record<string, any>) =>
   waitFor(() =>
     render(<HorizontalBar {...defaultProps} {...overrideProps} />, {
@@ -59,7 +53,7 @@ test('should not render the empty message', async () => {
     filterValues: [
       {
         id: 'test',
-        type: NativeFilterType.NATIVE_FILTER,
+        type: NativeFilterType.NativeFilter,
       },
     ],
   });
