@@ -18,7 +18,7 @@
  */
 
 import dashboardStateReducer from './dashboardState';
-import { setActiveTab, setActiveTabs } from '../actions/dashboardState';
+import { setActiveTab } from '../actions/dashboardState';
 
 describe('DashboardState reducer', () => {
   it('SET_ACTIVE_TAB', () => {
@@ -35,16 +35,4 @@ describe('DashboardState reducer', () => {
       ),
     ).toEqual({ activeTabs: ['tab2'] });
   });
-
-  it('SET_ACTIVE_TABS', () => {
-    expect(
-      dashboardStateReducer({ activeTabs: [] }, setActiveTabs(['tab1'])),
-    ).toEqual({ activeTabs: ['tab1'] });
-    expect(
-      dashboardStateReducer(
-        { activeTabs: ['tab1', 'tab2'] },
-        setActiveTabs(['tab3', 'tab4']),
-      ),
-    ).toEqual({ activeTabs: ['tab3', 'tab4'] });
-  });
 });
