@@ -50,6 +50,8 @@ describe('ResultsPaneOnDashboard', () => {
           ],
           colnames: ['__timestamp', 'genre'],
           coltypes: [2, 1],
+          rowcount: 2,
+          sql_rowcount: 2,
         },
       ],
     },
@@ -78,6 +80,8 @@ describe('ResultsPaneOnDashboard', () => {
           data: [{ genre: 'Action' }, { genre: 'Horror' }],
           colnames: ['genre'],
           coltypes: [1],
+          rowcount: 2,
+          sql_rowcount: 2,
         },
       ],
     },
