@@ -28,9 +28,13 @@ type RowCountLabelProps = {
   loading?: boolean;
 };
 
+const limitReachedMsg = t(
+  'The row limit set for the chart was reached. The chart may show partial data.',
+);
+
 export default function RowCountLabel(props: RowCountLabelProps) {
-  const { rowcount = 0, limit, loading } = props;
-  const limitReached = rowcount === limit;
+  const { rowcount = 0, limit = null, loading } = props;
+  const limitReached = limit && rowcount >= limit;
   const type =
     limitReached || (rowcount === 0 && !loading) ? 'danger' : 'default';
   const formattedRowCount = getNumberFormatter()(rowcount);
@@ -46,7 +50,7 @@ export default function RowCountLabel(props: RowCountLabelProps) {
     </Label>
   );
   return limitReached ? (
-    <Tooltip id="tt-rowcount-tooltip" title={<span>{t('Limit reached')}</span>}>
+    <Tooltip id="tt-rowcount-tooltip" title={<span>{limitReachedMsg}</span>}>
       {label}
     </Tooltip>
   ) : (
