@@ -297,6 +297,10 @@ function SavedQueryList({
         accessor: 'label',
         Header: t('Name'),
       },
+      {
+        accessor: 'description',
+        Header: t('Description'),
+      },
       {
         accessor: 'database.database_name',
         Header: t('Database'),
@@ -443,11 +447,13 @@ function SavedQueryList({
   const filters: Filters = useMemo(
     () => [
       {
-        Header: t('Name'),
+        Header: t('Search'),
         id: 'label',
         key: 'search',
         input: 'search',
         operator: FilterOperator.AllText,
+        toolTipDescription:
+          'Searches all text fields: Name, Description, Database & Schema',
       },
       {
         Header: t('Database'),
