@@ -19,18 +19,18 @@ import logging
 from flask import g, request, Response
 from flask_appbuilder.api import expose, protect, safe
 
-from superset.charts.commands.exceptions import ChartNotFoundError
+from superset.commands.chart.exceptions import ChartNotFoundError
+from superset.commands.explore.get import GetExploreCommand
+from superset.commands.explore.parameters import CommandParameters
+from superset.commands.temporary_cache.exceptions import (
+    TemporaryCacheAccessDeniedError,
+    TemporaryCacheResourceNotFoundError,
+)
 from superset.constants import MODEL_API_RW_METHOD_PERMISSION_MAP
-from superset.explore.commands.get import GetExploreCommand
-from superset.explore.commands.parameters import CommandParameters
 from superset.explore.exceptions import DatasetAccessDeniedError, WrongEndpointError
 from superset.explore.permalink.exceptions import ExplorePermalinkGetFailedError
 from superset.explore.schemas import ExploreContextSchema
 from superset.extensions import event_logger
-from superset.temporary_cache.commands.exceptions import (
-    TemporaryCacheAccessDeniedError,
-    TemporaryCacheResourceNotFoundError,
-)
 from superset.views.base_api import BaseSupersetApi, statsd_metrics
 
 logger = logging.getLogger(__name__)
@@ -53,16 +53,14 @@ class ExploreRestApi(BaseSupersetApi):
         log_to_statsd=True,
     )
     def get(self) -> Response:
-        """Assembles Explore related information (form_data, slice, dataset)
-         in a single endpoint.
+        """Assemble Explore related information (form_data, slice, dataset)
+        in a single endpoint.
         ---
         get:
-          summary: >-
-            Assembles Explore related information (form_data, slice, dataset)
-             in a single endpoint.
+          summary: Assemble Explore related information in a single endpoint
           description: >-
-            Assembles Explore related information (form_data, slice, dataset)
-             in a single endpoint.<br/><br/>
+            Assembles Explore related information (form_data, slice, dataset) in a
+            single endpoint.<br/><br/>
             The information can be assembled from:<br/>
             - The cache using a form_data_key<br/>
             - The metadata database using a permalink_key<br/>
