@@ -21,6 +21,9 @@ Revises: 4c5da39be729
 Create Date: 2023-06-08 11:34:36.241939
 
 """
+from alembic import op
+
+from superset import db
 
 # revision identifiers, used by Alembic.
 revision = "ae58e1e58e5c"
@@ -30,8 +33,12 @@ from superset.migrations.shared.migrate_viz.processors import MigrateDualLine
 
 
 def upgrade():
-    MigrateDualLine.upgrade()
+    bind = op.get_bind()
+    session = db.Session(bind=bind)
+    MigrateDualLine.upgrade(session)
 
 
 def downgrade():
-    MigrateDualLine.downgrade()
+    bind = op.get_bind()
+    session = db.Session(bind=bind)
+    MigrateDualLine.downgrade(session)
