@@ -24,7 +24,7 @@ from flask_appbuilder.security.decorators import permission_name, protect
 from flask_wtf.csrf import generate_csrf
 from marshmallow import EXCLUDE, fields, post_load, Schema, ValidationError
 
-from superset.embedded_dashboard.commands.exceptions import (
+from superset.commands.dashboard.embedded.exceptions import (
     EmbeddedDashboardNotFoundError,
 )
 from superset.extensions import event_logger
@@ -54,7 +54,7 @@ class ResourceSchema(PermissiveSchema):
     id = fields.String(required=True)
 
     @post_load
-    def convert_enum_to_value(  # pylint: disable=no-self-use
+    def convert_enum_to_value(
         self, data: dict[str, Any], **kwargs: Any  # pylint: disable=unused-argument
     ) -> dict[str, Any]:
         # we don't care about the enum, we want the value inside
@@ -88,12 +88,10 @@ class SecurityRestApi(BaseSupersetApi):
     @statsd_metrics
     @permission_name("read")
     def csrf_token(self) -> Response:
-        """
-        Return the csrf token
+        """Get the CSRF token.
         ---
         get:
-          description: >-
-            Fetch the CSRF token
+          summary: Get the CSRF token
           responses:
             200:
               description: Result contains the CSRF token
@@ -118,12 +116,10 @@ class SecurityRestApi(BaseSupersetApi):
     @statsd_metrics
     @permission_name("grant_guest_token")
     def guest_token(self) -> Response:
-        """Response
-        Returns a guest token that can be used for auth in embedded Superset
+        """Get a guest token that can be used for auth in embedded Superset.
         ---
         post:
-          description: >-
-            Fetches a guest token
+          summary: Get a guest token
           requestBody:
             description: Parameters for the guest token
             required: true
