@@ -146,7 +146,8 @@ class CsvToDatabaseForm(UploadToDatabaseForm):
         description=_(
             "A dictionary with column names and their data types"
             " if you need to change the defaults."
-            ' Example: {"user_id":"integer"}'
+            ' Example: {"user_id":"int"}. '
+            "Check Python's Pandas library for supported data types."
         ),
         validators=[Optional()],
         widget=BS3TextFieldWidget(),
