@@ -114,10 +114,6 @@ class TestDatasetApi(SupersetTestCase):
     @pytest.fixture()
     def create_virtual_datasets(self):
         with self.create_app().app_context():
-            if backend() == "sqlite":
-                yield
-                return
-
             datasets = []
             admin = self.get_user("admin")
             main_db = get_main_database()
@@ -140,10 +136,6 @@ class TestDatasetApi(SupersetTestCase):
     @pytest.fixture()
     def create_datasets(self):
         with self.create_app().app_context():
-            if backend() == "sqlite":
-                yield
-                return
-
             datasets = []
             admin = self.get_user("admin")
             main_db = get_main_database()
@@ -192,8 +184,6 @@ class TestDatasetApi(SupersetTestCase):
         """
         Dataset API: Test get dataset list
         """
-        if backend() == "sqlite":
-            return
 
         example_db = get_example_database()
         self.login(username="admin")
@@ -232,8 +222,6 @@ class TestDatasetApi(SupersetTestCase):
         """
         Dataset API: Test get dataset list gamma
         """
-        if backend() == "sqlite":
-            return
 
         self.login(username="gamma")
         uri = "api/v1/dataset/"
@@ -246,8 +234,6 @@ class TestDatasetApi(SupersetTestCase):
         """
         Dataset API: Test get dataset list with database access
         """
-        if backend() == "sqlite":
-            return
 
         self.login(username="gamma")
 
@@ -289,8 +275,6 @@ class TestDatasetApi(SupersetTestCase):
         """
         Dataset API: Test get dataset related databases gamma
         """
-        if backend() == "sqlite":
-            return
 
         # Add main database access to gamma role
         main_db = get_main_database()
@@ -320,8 +304,6 @@ class TestDatasetApi(SupersetTestCase):
         """
         Dataset API: Test get dataset item
         """
-        if backend() == "sqlite":
-            return
 
         table = self.get_energy_usage_dataset()
         main_db = get_main_database()
@@ -385,8 +367,6 @@ class TestDatasetApi(SupersetTestCase):
         """
         Dataset API: Test get dataset distinct schema
         """
-        if backend() == "sqlite":
-            return
 
         def pg_test_query_parameter(query_parameter, expected_response):
             uri = f"api/v1/dataset/distinct/schema?q={prison.dumps(query_parameter)}"
@@ -459,8 +439,6 @@ class TestDatasetApi(SupersetTestCase):
         """
         Dataset API: Test get dataset distinct not allowed
         """
-        if backend() == "sqlite":
-            return
 
         self.login(username="admin")
         uri = "api/v1/dataset/distinct/table_name"
@@ -471,8 +449,6 @@ class TestDatasetApi(SupersetTestCase):
         """
         Dataset API: Test get dataset distinct with gamma
         """
-        if backend() == "sqlite":
-            return
 
         dataset = self.insert_default_dataset()
 
@@ -491,8 +467,6 @@ class TestDatasetApi(SupersetTestCase):
         """
         Dataset API: Test get dataset info
         """
-        if backend() == "sqlite":
-            return
 
         self.login(username="admin")
         uri = "api/v1/dataset/_info"
@@ -503,8 +477,6 @@ class TestDatasetApi(SupersetTestCase):
         """
         Dataset API: Test info security
         """
-        if backend() == "sqlite":
-            return
 
         self.login(username="admin")
         params = {"keys": ["permissions"]}
@@ -525,8 +497,6 @@ class TestDatasetApi(SupersetTestCase):
         """
         Dataset API: Test create dataset item
         """
-        if backend() == "sqlite":
-            return
 
         main_db = get_main_database()
         self.login(username="admin")
@@ -572,8 +542,6 @@ class TestDatasetApi(SupersetTestCase):
         """
         Dataset API: Test create dataset item with column normalization enabled
         """
-        if backend() == "sqlite":
-            return
 
         main_db = get_main_database()
         self.login(username="admin")
@@ -601,8 +569,6 @@ class TestDatasetApi(SupersetTestCase):
         """
         Dataset API: Test create dataset item gamma
         """
-        if backend() == "sqlite":
-            return
 
         self.login(username="gamma")
         main_db = get_main_database()
@@ -619,8 +585,6 @@ class TestDatasetApi(SupersetTestCase):
         """
         Dataset API: Test create item owner
         """
-        if backend() == "sqlite":
-            return
 
         main_db = get_main_database()
         self.login(username="alpha")
@@ -647,8 +611,6 @@ class TestDatasetApi(SupersetTestCase):
         """
         Dataset API: Test create dataset item owner invalid
         """
-        if backend() == "sqlite":
-            return
 
         admin = self.get_user("admin")
         main_db = get_main_database()
@@ -671,8 +633,6 @@ class TestDatasetApi(SupersetTestCase):
         """
         Dataset API: Test create dataset validate table uniqueness
         """
-        if backend() == "sqlite":
-            return
 
         energy_usage_ds = self.get_energy_usage_dataset()
         self.login(username="admin")
@@ -694,8 +654,6 @@ class TestDatasetApi(SupersetTestCase):
         """
         Dataset API: Test create dataset with sql
         """
-        if backend() == "sqlite":
-            return
 
         energy_usage_ds = self.get_energy_usage_dataset()
         self.login(username="admin")
@@ -718,8 +676,6 @@ class TestDatasetApi(SupersetTestCase):
         """
         Dataset API: Test create dataset with sql
         """
-        if backend() == "sqlite":
-            return
 
         energy_usage_ds = self.get_energy_usage_dataset()
         self.login(username="alpha")
@@ -777,8 +733,6 @@ class TestDatasetApi(SupersetTestCase):
         """
         Dataset API: Test create dataset validate database exists
         """
-        if backend() == "sqlite":
-            return
 
         self.login(username="admin")
         dataset_data = {"database": 1000, "schema": "", "table_name": "birth_names"}
@@ -792,8 +746,6 @@ class TestDatasetApi(SupersetTestCase):
         """
         Dataset API: Test create dataset validate table exists
         """
-        if backend() == "sqlite":
-            return
 
         example_db = get_example_database()
         self.login(username="admin")
@@ -820,8 +772,6 @@ class TestDatasetApi(SupersetTestCase):
         """
         Dataset API: Test create dataset validate view exists
         """
-        if backend() == "sqlite":
-            return
 
         mock_get_columns.return_value = [
             {
@@ -868,8 +818,6 @@ class TestDatasetApi(SupersetTestCase):
         """
         Dataset API: Test create dataset sqlalchemy error
         """
-        if backend() == "sqlite":
-            return
 
         mock_dao_create.side_effect = DAOCreateFailedError()
         self.login(username="admin")
@@ -889,8 +837,6 @@ class TestDatasetApi(SupersetTestCase):
         """
         Dataset API: Test update dataset preserves owner list (if un-changed)
         """
-        if backend() == "sqlite":
-            return
 
         dataset = self.insert_default_dataset()
         current_owners = dataset.owners
@@ -909,8 +855,6 @@ class TestDatasetApi(SupersetTestCase):
         """
         Dataset API: Test update dataset admin can clear ownership config
         """
-        if backend() == "sqlite":
-            return
 
         dataset = self.insert_default_dataset()
         self.login(username="admin")
@@ -929,8 +873,6 @@ class TestDatasetApi(SupersetTestCase):
         Dataset API: Test update admin can update dataset with
         no owners to a different owner
         """
-        if backend() == "sqlite":
-            return
         self.login(username="admin")
         gamma = self.get_user("gamma")
         dataset = self.insert_dataset("ab_permission", [], get_main_database())
@@ -948,8 +890,6 @@ class TestDatasetApi(SupersetTestCase):
         """
         Dataset API: Test update dataset item
         """
-        if backend() == "sqlite":
-            return
 
         dataset = self.insert_default_dataset()
         current_owners = dataset.owners
@@ -969,8 +909,6 @@ class TestDatasetApi(SupersetTestCase):
         """
         Dataset API: Test update dataset with override columns
         """
-        if backend() == "sqlite":
-            return
 
         # Add default dataset
         dataset = self.insert_default_dataset()
@@ -1008,8 +946,6 @@ class TestDatasetApi(SupersetTestCase):
         """
         Dataset API: Test update dataset with override columns
         """
-        if backend() == "sqlite":
-            return
 
         # Add default dataset
         main_db = get_main_database()
@@ -1058,8 +994,6 @@ class TestDatasetApi(SupersetTestCase):
         """
         Dataset API: Test update dataset create column
         """
-        if backend() == "sqlite":
-            return
 
         # create example dataset by Command
         dataset = self.insert_default_dataset()
@@ -1156,8 +1090,6 @@ class TestDatasetApi(SupersetTestCase):
         """
         Dataset API: Test update dataset delete column
         """
-        if backend() == "sqlite":
-            return
 
         # create example dataset by Command
         dataset = self.insert_default_dataset()
@@ -1208,8 +1140,6 @@ class TestDatasetApi(SupersetTestCase):
         """
         Dataset API: Test update dataset columns
         """
-        if backend() == "sqlite":
-            return
 
         dataset = self.insert_default_dataset()
 
@@ -1247,8 +1177,6 @@ class TestDatasetApi(SupersetTestCase):
         """
         Dataset API: Test update dataset delete metric
         """
-        if backend() == "sqlite":
-            return
 
         dataset = self.insert_default_dataset()
         metrics_query = (
@@ -1293,8 +1221,6 @@ class TestDatasetApi(SupersetTestCase):
         """
         Dataset API: Test update dataset columns uniqueness
         """
-        if backend() == "sqlite":
-            return
 
         dataset = self.insert_default_dataset()
 
@@ -1316,8 +1242,6 @@ class TestDatasetApi(SupersetTestCase):
         """
         Dataset API: Test update dataset metric uniqueness
         """
-        if backend() == "sqlite":
-            return
 
         dataset = self.insert_default_dataset()
 
@@ -1339,8 +1263,6 @@ class TestDatasetApi(SupersetTestCase):
         """
         Dataset API: Test update dataset columns duplicate
         """
-        if backend() == "sqlite":
-            return
 
         dataset = self.insert_default_dataset()
 
@@ -1367,8 +1289,6 @@ class TestDatasetApi(SupersetTestCase):
         """
         Dataset API: Test update dataset metric duplicate
         """
-        if backend() == "sqlite":
-            return
 
         dataset = self.insert_default_dataset()
 
@@ -1395,8 +1315,6 @@ class TestDatasetApi(SupersetTestCase):
         """
         Dataset API: Test update dataset item gamma
         """
-        if backend() == "sqlite":
-            return
 
         dataset = self.insert_default_dataset()
         self.login(username="gamma")
@@ -1411,8 +1329,6 @@ class TestDatasetApi(SupersetTestCase):
         """
         Dataset API: Tests that no username is returned
         """
-        if backend() == "sqlite":
-            return
 
         dataset = self.insert_default_dataset()
         self.login(username="admin")
@@ -1435,8 +1351,6 @@ class TestDatasetApi(SupersetTestCase):
         """
         Dataset API: Tests that no username is returned
         """
-        if backend() == "sqlite":
-            return
 
         dataset = self.insert_default_dataset()
         self.login(username="admin")
@@ -1458,8 +1372,6 @@ class TestDatasetApi(SupersetTestCase):
         """
         Dataset API: Test update dataset item not owned
         """
-        if backend() == "sqlite":
-            return
 
         dataset = self.insert_default_dataset()
         self.login(username="alpha")
@@ -1474,8 +1386,6 @@ class TestDatasetApi(SupersetTestCase):
         """
         Dataset API: Test update dataset item owner invalid
         """
-        if backend() == "sqlite":
-            return
 
         dataset = self.insert_default_dataset()
         self.login(username="admin")
@@ -1490,8 +1400,6 @@ class TestDatasetApi(SupersetTestCase):
         """
         Dataset API: Test update dataset uniqueness
         """
-        if backend() == "sqlite":
-            return
 
         dataset = self.insert_default_dataset()
         self.login(username="admin")
@@ -1516,8 +1424,6 @@ class TestDatasetApi(SupersetTestCase):
         """
         Dataset API: Test update dataset sqlalchemy error
         """
-        if backend() == "sqlite":
-            return
 
         mock_dao_update.side_effect = DAOUpdateFailedError()
 
@@ -1537,8 +1443,6 @@ class TestDatasetApi(SupersetTestCase):
         """
         Dataset API: Test delete dataset item
         """
-        if backend() == "sqlite":
-            return
 
         dataset = self.insert_default_dataset()
         view_menu = security_manager.find_view_menu(dataset.get_perm())
@@ -1557,8 +1461,6 @@ class TestDatasetApi(SupersetTestCase):
         """
         Dataset API: Test delete item not owned
         """
-        if backend() == "sqlite":
-            return
 
         dataset = self.insert_default_dataset()
         self.login(username="alpha")
@@ -1572,8 +1474,6 @@ class TestDatasetApi(SupersetTestCase):
         """
         Dataset API: Test delete item not authorized
         """
-        if backend() == "sqlite":
-            return
 
         dataset = self.insert_default_dataset()
         self.login(username="gamma")
@@ -1588,8 +1488,6 @@ class TestDatasetApi(SupersetTestCase):
         """
         Dataset API: Test delete dataset sqlalchemy error
         """
-        if backend() == "sqlite":
-            return
 
         mock_dao_delete.side_effect = DAODeleteFailedError()
 
@@ -1608,8 +1506,6 @@ class TestDatasetApi(SupersetTestCase):
         """
         Dataset API: Test delete dataset column
         """
-        if backend() == "sqlite":
-            return
 
         dataset = self.get_fixture_datasets()[0]
         column_id = dataset.columns[0].id
@@ -1624,8 +1520,6 @@ class TestDatasetApi(SupersetTestCase):
         """
         Dataset API: Test delete dataset column not found
         """
-        if backend() == "sqlite":
-            return
 
         dataset = self.get_fixture_datasets()[0]
         non_id = self.get_nonexistent_numeric_id(TableColumn)
@@ -1648,8 +1542,6 @@ class TestDatasetApi(SupersetTestCase):
         """
         Dataset API: Test delete dataset column not owned
         """
-        if backend() == "sqlite":
-            return
 
         dataset = self.get_fixture_datasets()[0]
         column_id = dataset.columns[0].id
@@ -1665,8 +1557,6 @@ class TestDatasetApi(SupersetTestCase):
         """
         Dataset API: Test delete dataset column
         """
-        if backend() == "sqlite":
-            return
 
         mock_dao_delete.side_effect = DAODeleteFailedError()
         dataset = self.get_fixture_datasets()[0]
@@ -1683,8 +1573,6 @@ class TestDatasetApi(SupersetTestCase):
         """
         Dataset API: Test delete dataset metric
         """
-        if backend() == "sqlite":
-            return
 
         dataset = self.get_fixture_datasets()[0]
         test_metric = SqlMetric(
@@ -1704,8 +1592,6 @@ class TestDatasetApi(SupersetTestCase):
         """
         Dataset API: Test delete dataset metric not found
         """
-        if backend() == "sqlite":
-            return
 
         dataset = self.get_fixture_datasets()[0]
         non_id = self.get_nonexistent_numeric_id(SqlMetric)
@@ -1728,8 +1614,6 @@ class TestDatasetApi(SupersetTestCase):
         """
         Dataset API: Test delete dataset metric not owned
         """
-        if backend() == "sqlite":
-            return
 
         dataset = self.get_fixture_datasets()[0]
         metric_id = dataset.metrics[0].id
@@ -1745,8 +1629,6 @@ class TestDatasetApi(SupersetTestCase):
         """
         Dataset API: Test delete dataset metric
         """
-        if backend() == "sqlite":
-            return
 
         mock_dao_delete.side_effect = DAODeleteFailedError()
         dataset = self.get_fixture_datasets()[0]
@@ -1763,8 +1645,6 @@ class TestDatasetApi(SupersetTestCase):
         """
         Dataset API: Test bulk delete dataset items
         """
-        if backend() == "sqlite":
-            return
 
         datasets = self.get_fixture_datasets()
         dataset_ids = [dataset.id for dataset in datasets]
@@ -1795,8 +1675,6 @@ class TestDatasetApi(SupersetTestCase):
         """
         Dataset API: Test bulk delete item not owned
         """
-        if backend() == "sqlite":
-            return
 
         datasets = self.get_fixture_datasets()
         dataset_ids = [dataset.id for dataset in datasets]
@@ -1811,8 +1689,6 @@ class TestDatasetApi(SupersetTestCase):
         """
         Dataset API: Test bulk delete item not found
         """
-        if backend() == "sqlite":
-            return
 
         datasets = self.get_fixture_datasets()
         dataset_ids = [dataset.id for dataset in datasets]
@@ -1828,8 +1704,6 @@ class TestDatasetApi(SupersetTestCase):
         """
         Dataset API: Test bulk delete item not authorized
         """
-        if backend() == "sqlite":
-            return
 
         datasets = self.get_fixture_datasets()
         dataset_ids = [dataset.id for dataset in datasets]
@@ -1844,8 +1718,6 @@ class TestDatasetApi(SupersetTestCase):
         """
         Dataset API: Test bulk delete item incorrect request
         """
-        if backend() == "sqlite":
-            return
 
         datasets = self.get_fixture_datasets()
         dataset_ids = [dataset.id for dataset in datasets]
@@ -1860,8 +1732,6 @@ class TestDatasetApi(SupersetTestCase):
         """
         Dataset API: Test item refresh
         """
-        if backend() == "sqlite":
-            return
 
         dataset = self.insert_default_dataset()
         # delete a column
@@ -1891,8 +1761,6 @@ class TestDatasetApi(SupersetTestCase):
         """
         Dataset API: Test item refresh not found dataset
         """
-        if backend() == "sqlite":
-            return
 
         max_id = db.session.query(func.max(SqlaTable.id)).scalar()
 
@@ -1905,8 +1773,6 @@ class TestDatasetApi(SupersetTestCase):
         """
         Dataset API: Test item refresh not owned dataset
         """
-        if backend() == "sqlite":
-            return
 
         dataset = self.insert_default_dataset()
         self.login(username="alpha")
@@ -1922,8 +1788,6 @@ class TestDatasetApi(SupersetTestCase):
         """
         Dataset API: Test export dataset
         """
-        if backend() == "sqlite":
-            return
 
         birth_names_dataset = self.get_birth_names_dataset()
         # TODO: fix test for presto
@@ -1939,7 +1803,6 @@ class TestDatasetApi(SupersetTestCase):
         assert rv.status_code == 200
 
         cli_export = export_to_dict(
-            session=db.session,
             recursive=True,
             back_references=False,
             include_defaults=False,
@@ -1957,8 +1820,6 @@ class TestDatasetApi(SupersetTestCase):
         """
         Dataset API: Test export dataset not found
         """
-        if backend() == "sqlite":
-            return
 
         max_id = db.session.query(func.max(SqlaTable.id)).scalar()
         # Just one does not exist and we get 404
@@ -1973,8 +1834,6 @@ class TestDatasetApi(SupersetTestCase):
         """
         Dataset API: Test export dataset has gamma
         """
-        if backend() == "sqlite":
-            return
 
         dataset = self.get_fixture_datasets()[0]
 
@@ -2004,8 +1863,6 @@ class TestDatasetApi(SupersetTestCase):
         """
         Dataset API: Test export dataset
         """
-        if backend() == "sqlite":
-            return
 
         birth_names_dataset = self.get_birth_names_dataset()
         # TODO: fix test for presto
@@ -2028,8 +1885,6 @@ class TestDatasetApi(SupersetTestCase):
         """
         Dataset API: Test export dataset not found
         """
-        if backend() == "sqlite":
-            return
 
         # Just one does not exist and we get 404
         argument = [-1, 1]
@@ -2044,8 +1899,6 @@ class TestDatasetApi(SupersetTestCase):
         """
         Dataset API: Test export dataset has gamma
         """
-        if backend() == "sqlite":
-            return
 
         dataset = self.get_fixture_datasets()[0]
 
@@ -2064,8 +1917,6 @@ class TestDatasetApi(SupersetTestCase):
         Dataset API: Test get chart and dashboard count related to a dataset
         :return:
         """
-        if backend() == "sqlite":
-            return
 
         self.login(username="admin")
         table = self.get_birth_names_dataset()
@@ -2080,8 +1931,6 @@ class TestDatasetApi(SupersetTestCase):
         """
         Dataset API: Test related objects not found
         """
-        if backend() == "sqlite":
-            return
 
         max_id = db.session.query(func.max(SqlaTable.id)).scalar()
         # id does not exist and we get 404
@@ -2103,8 +1952,6 @@ class TestDatasetApi(SupersetTestCase):
         """
         Dataset API: Test custom dataset_is_null_or_empty filter for sql
         """
-        if backend() == "sqlite":
-            return
 
         arguments = {
             "filters": [
@@ -2139,8 +1986,6 @@ class TestDatasetApi(SupersetTestCase):
         """
         Dataset API: Test import dataset
         """
-        if backend() == "sqlite":
-            return
 
         self.login(username="admin")
         uri = "api/v1/dataset/import/"
@@ -2174,9 +2019,6 @@ class TestDatasetApi(SupersetTestCase):
         db.session.commit()
 
     def test_import_dataset_v0_export(self):
-        if backend() == "sqlite":
-            return
-
         num_datasets = db.session.query(SqlaTable).count()
 
         self.login(username="admin")
@@ -2207,8 +2049,6 @@ class TestDatasetApi(SupersetTestCase):
         """
         Dataset API: Test import existing dataset
         """
-        if backend() == "sqlite":
-            return
 
         self.login(username="admin")
         uri = "api/v1/dataset/import/"
@@ -2278,8 +2118,6 @@ class TestDatasetApi(SupersetTestCase):
         """
         Dataset API: Test import invalid dataset
         """
-        if backend() == "sqlite":
-            return
 
         self.login(username="admin")
         uri = "api/v1/dataset/import/"
@@ -2331,8 +2169,6 @@ class TestDatasetApi(SupersetTestCase):
         """
         Dataset API: Test import invalid dataset
         """
-        if backend() == "sqlite":
-            return
 
         self.login(username="admin")
         uri = "api/v1/dataset/import/"
@@ -2379,8 +2215,6 @@ class TestDatasetApi(SupersetTestCase):
         """
         Dataset API: Test custom dataset_is_certified filter
         """
-        if backend() == "sqlite":
-            return
 
         table_w_certification = SqlaTable(
             table_name="foo",
@@ -2412,8 +2246,6 @@ class TestDatasetApi(SupersetTestCase):
         """
         Dataset API: Test duplicate virtual dataset
         """
-        if backend() == "sqlite":
-            return
 
         dataset = self.get_fixture_virtual_datasets()[0]
 
@@ -2440,8 +2272,6 @@ class TestDatasetApi(SupersetTestCase):
         """
         Dataset API: Test duplicate physical dataset
         """
-        if backend() == "sqlite":
-            return
 
         dataset = self.get_fixture_datasets()[0]
 
@@ -2456,8 +2286,6 @@ class TestDatasetApi(SupersetTestCase):
         """
         Dataset API: Test duplicate dataset with existing name
         """
-        if backend() == "sqlite":
-            return
 
         dataset = self.get_fixture_virtual_datasets()[0]
 
@@ -2568,9 +2396,10 @@ class TestDatasetApi(SupersetTestCase):
         assert table.normalize_columns is False
 
         db.session.delete(table)
+        db.session.commit()
+
         with examples_db.get_sqla_engine_with_context() as engine:
             engine.execute("DROP TABLE test_create_sqla_table_api")
-        db.session.commit()
 
     @pytest.mark.usefixtures(
         "load_energy_table_with_slice", "load_birth_names_dashboard_with_slices"
